@@ -106,8 +106,9 @@ from .radial_column_density.api import \
     RadialColumnDensity
 
 from .spectral_integrator.api import \
-    SpectralFrequencyIntegrator, \
-    create_table_from_textfiles
+     add_xray_emissivity_field, \
+     add_xray_luminosity_field, \
+     add_xray_photon_emissivity_field
 
 from .star_analysis.api import \
     StarFormationRate, \
