@@ -9,9 +9,16 @@ def configuration(parent_package='',top_path=None):
     config = Configuration('rockstar',parent_package,top_path)
     config.make_config_py() # installs __config__.py
     #config.make_svn_version_py()
-    rd = os.environ["ROCKSTAR_DIR"]
+    try:
+        rd = open("rockstar.cfg").read().strip()
+    except IOError:
+        print "Reading Rockstar location from rockstar.cfg failed."
+        print "Please place the base directory of your"
+        print "Rockstar install in rockstar.cfg and restart."
+        print "(ex: \"echo '/path/to/Rockstar-0.99' > rockstar.cfg\" )"
+        sys.exit(1)
     config.add_extension("rockstar_interface",
-                         "yt/analysis_modules/halo_finding/rockstar/rockstar_interface.pyx",
+                         "yt/analysis_modules/halo_finding/rockstar/rockstar_interface.c",
                          library_dirs=[rd],
                          libraries=["rockstar"],
                          include_dirs=[rd,
