@@ -23,7 +23,7 @@ License:
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import numpy as na
+import numpy as np
 import os
 import h5py
 import types
@@ -59,7 +59,130 @@ from yt.visualization.image_writer import write_image
 PROFILE_RADIUS_THRESHOLD = 2
 
 class HaloProfiler(ParallelAnalysisInterface):
-    "Radial profiling, filtering, and projections for halos in cosmological simulations."
+    r"""Initialize a Halo Profiler object.
+
+    In order to run the halo profiler, the Halo Profiler object must be
+    instantiated. At the minimum, the path to a parameter file
+    must be provided as the first term.
+
+    Parameters
+    ----------
+
+    dataset : string, required
+        The path to the parameter file for the dataset to be analyzed.
+    output_dir : string, optional
+        If specified, all output will be put into this path instead of
+        in the dataset directories.  Default: None.
+    halos :  {"multiple", "single"}, optional
+        For profiling more than one halo.  In this mode halos are read in
+        from a list or identified with a halo finder.  In "single" mode,
+        the one and only halo
+        center is identified automatically as the location of the peak
+        in the density field.
+        Default: "multiple".
+    halo_list_file : string, optional
+        The name of a file containing the list of halos.  The HaloProfiler
+        will  look for this file in the data directory.
+        Default: "HopAnalysis.out".
+    halo_list_format : {string, dict}
+        The format of the halo list file.  "yt_hop" for the format
+        given by yt's halo finders.  "enzo_hop" for the format written
+        by enzo_hop. "p-groupfinder"  for P-Groupfinder.  This keyword
+        can also be given in the form of a dictionary specifying the
+        column in which various properties can be found.
+        For example, {"id": 0, "center": [1, 2, 3], "mass": 4, "radius": 5}.
+        Default: "yt_hop".
+    halo_finder_function : function
+        If halos is set to multiple and the file given by
+        halo_list_file does not exit, the halo finding function
+        specified here will be called.
+        Default: HaloFinder (yt_hop).
+    halo_finder_args : tuple
+        Args given with call to halo finder function.  Default: None.
+    halo_finder_kwargs : dict
+        kwargs given with call to halo finder function. Default: None.
+    recenter : {string, function}
+        The exact location of the sphere center can significantly affect
+        radial profiles.  The halo center loaded by the HaloProfiler will
+        typically be the dark matter center of mass calculated by a halo
+        finder.  However, this may not be the best location for centering
+        profiles of baryon quantities.  For example, one may want to center
+        on the maximum density.
+        If recenter is given as a string, one of the existing recentering
+        functions will be used:
+
+            * Min_Dark_Matter_Density : location of minimum dark matter density
+            * Max_Dark_Matter_Density : location of maximum dark matter density
+            * CoM_Dark_Matter_Density : dark matter center of mass
+            * Min_Gas_Density : location of minimum gas density
+            * Max_Gas_Density : location of maximum gas density
+            * CoM_Gas_Density : gas center of mass
+            * Min_Total_Density : location of minimum total density
+            * Max_Total_Density : location of maximum total density
+            * CoM_Total_Density : total center of mass
+            * Min_Temperature : location of minimum temperature
+            * Max_Temperature : location of maximum temperature
+
+        Alternately, a function can be supplied for custom recentering.
+        The function should take only one argument, a sphere object.  Example
+        function::
+            
+               def my_center_of_mass(data):
+                   my_x, my_y, my_z = data.quantities['CenterOfMass']()
+                   return (my_x, my_y, my_z)
+            
+        Default: None.
+    halo_radius : float
+        If no halo radii are provided in the halo list file, this
+        parameter is used to specify the radius out to which radial
+        profiles will be made.  This keyword is also
+        used when halos is set to single.  Default: 0.1.
+    radius_units : string
+        The units of halo_radius.  Default: "1" (code units).
+    n_profile_bins : int
+        The number of bins in the radial profiles.  Default: 50.
+    profile_output_dir : str
+        The subdirectory, inside the data directory, in which radial profile
+        output files will be created.  The directory will be created if it does
+        not exist.  Default: "radial_profiles".
+    projection_output_dir : str
+        The subdirectory, inside the data directory, in which projection
+        output files will be created.  The directory will be created if it does
+        not exist.  Default: "projections".
+    projection_width : float
+        The width of halo projections.  Default: 8.0.
+    projection_width_units : string
+        The units of projection_width. Default: "mpc".
+    project_at_level : {"max", int}
+        The maximum refinement level to be included in projections.
+        Default: "max" (maximum level within the dataset).
+    velocity_center  : array_like
+        The method in which the halo bulk velocity is calculated (used for
+        calculation of radial and tangential velocities.  Valid options are:
+
+            * ["bulk", "halo"] (Default): the velocity provided in
+              the halo list
+            * ["bulk", "sphere"]: the bulk velocity of the sphere
+              centered on the halo center.
+            * ["max", field]: the velocity of the cell that is the
+              location of the maximum of the field specified.
+
+    filter_quantities : array_like
+        Quantities from the original halo list file to be written out in the
+        filtered list file.  Default: ['id','center'].
+    use_critical_density : bool
+        If True, the definition of overdensity for virial quantities
+        is calculated with respect to the critical density.
+        If False, overdensity is with respect to mean matter density,
+        which is lower by a factor of Omega_M.  Default: False.
+
+    Examples
+    --------
+
+    >>> from yt.analysis_modules.halo_profiler.api import *
+    >>> hp = HaloProfiler("RedshiftOutput0005/RD0005")
+
+    """
     def __init__(self, dataset, output_dir=None,
                  halos='multiple', halo_list_file='HopAnalysis.out',
                  halo_list_format='yt_hop', halo_finder_function=parallelHF,
@@ -73,125 +196,6 @@ class HaloProfiler(ParallelAnalysisInterface):
                  projection_width=8.0, projection_width_units='mpc', project_at_level='max',
                  velocity_center=['bulk', 'halo'], filter_quantities=['id', 'center', 'r_max'],
                  use_critical_density=False):
-        r"""Initialize a Halo Profiler object.
-
-        In order to run the halo profiler, the Halo Profiler object must be
-        instantiated. At the minimum, the path to a parameter file
-        must be provided as the first term.
-
-        Parameters
-        ----------
-
-        dataset : string, required
-            The path to the parameter file for the dataset to be analyzed.
-        output_dir : string, optional
-            If specified, all output will be put into this path instead of
-            in the dataset directories.  Default: None.
-        halos :  {"multiple", "single"}, optional
-            For profiling more than one halo.  In this mode halos are read in
-            from a list or identified with a halo finder.  In "single" mode,
-            the one and only halo
-            center is identified automatically as the location of the peak
-            in the density field.
-            Default: "multiple".
-        halo_list_file : string, optional
-            The name of a file containing the list of halos.  The HaloProfiler
-            will  look for this file in the data directory.
-            Default: "HopAnalysis.out".
-        halo_list_format : {string, dict}
-            The format of the halo list file.  "yt_hop" for the format
-            given by yt's halo finders.  "enzo_hop" for the format written
-            by enzo_hop. "p-groupfinder"  for P-Groupfinder.  This keyword
-            can also be given in the form of a dictionary specifying the
-            column in which various properties can be found.
-            For example, {"id": 0, "center": [1, 2, 3], "mass": 4, "radius": 5}.
-            Default: "yt_hop".
-        halo_finder_function : function
-            If halos is set to multiple and the file given by
-            halo_list_file does not exit, the halo finding function
-            specified here will be called.
-            Default: HaloFinder (yt_hop).
-        halo_finder_args : tuple
-            Args given with call to halo finder function.  Default: None.
-        halo_finder_kwargs : dict
-            kwargs given with call to halo finder function. Default: None.
-        recenter : {string, function}
-            The exact location of the sphere center can significantly affect
-            radial profiles.  The halo center loaded by the HaloProfiler will
-            typically be the dark matter center of mass calculated by a halo
-            finder.  However, this may not be the best location for centering
-            profiles of baryon quantities.  For example, one may want to center
-            on the maximum density.
-            If recenter is given as a string, one of the existing recentering
-            functions will be used:
-                Min_Dark_Matter_Density : location of minimum dark matter density
-                Max_Dark_Matter_Density : location of maximum dark matter density
-                CoM_Dark_Matter_Density : dark matter center of mass
-                Min_Gas_Density : location of minimum gas density
-                Max_Gas_Density : location of maximum gas density
-                CoM_Gas_Density : gas center of mass
-                Min_Total_Density : location of minimum total density
-                Max_Total_Density : location of maximum total density
-                CoM_Total_Density : total center of mass
-                Min_Temperature : location of minimum temperature
-                Max_Temperature : location of maximum temperature
-            Alternately, a function can be supplied for custom recentering.
-            The function should take only one argument, a sphere object.
-                Example function:
-                    def my_center_of_mass(data):
-                       my_x, my_y, my_z = data.quantities['CenterOfMass']()
-                       return (my_x, my_y, my_z)
-            Default: None.
-        halo_radius : float
-            If no halo radii are provided in the halo list file, this
-            parameter is used to specify the radius out to which radial
-            profiles will be made.  This keyword is also
-            used when halos is set to single.  Default: 0.1.
-        radius_units : string
-            The units of halo_radius.  Default: "1" (code units).
-        n_profile_bins : int
-            The number of bins in the radial profiles.  Default: 50.
-        profile_output_dir : str
-            The subdirectory, inside the data directory, in which radial profile
-            output files will be created.
-            The directory will be created if it does not exist.
-            Default: "radial_profiles".
-        projection_output_dir : str
-            The subdirectory, inside the data directory, in which projection
-            output files will be created.
-            The directory will be created if it does not exist.
-            Default: "projections".
-        projection_width : float
-            The width of halo projections.  Default: 8.0.
-        projection_width_units : string
-            The units of projection_width. Default: "mpc".
-        project_at_level : {"max", int}
-            The maximum refinement level to be included in projections.
-            Default: "max" (maximum level within the dataset).
-        velocity_center  : array_like
-            The method in which the halo bulk velocity is calculated (used for
-            calculation of radial and tangential velocities.  Valid options are:
-     	        * ["bulk", "halo"] (Default): the velocity provided in
-     	          the halo list
-                * ["bulk", "sphere"]: the bulk velocity of the sphere
-                  centered on the halo center.
-    	        * ["max", field]: the velocity of the cell that is the
-    	          location of the maximum of the field specified.
-        filter_quantities : array_like
-            Quantities from the original halo list file to be written out in the
-            filtered list file.  Default: ['id','center'].
-        use_critical_density : bool
-            If True, the definition of overdensity for virial quantities
-            is calculated with respect to the critical density.
-            If False, overdensity is with respect to mean matter density,
-            which is lower by a factor of Omega_M.  Default: False.
-
-        Examples
-        --------
-        >>> from yt.analysis_modules.halo_profiler.api import *
-        >>> hp = HaloProfiler("RedshiftOutput0005/RD0005")
-
-        """
         ParallelAnalysisInterface.__init__(self)
 
         self.dataset = dataset
@@ -281,10 +285,10 @@ class HaloProfiler(ParallelAnalysisInterface):
         # Create output directories.
         self.output_dir = output_dir
         if output_dir is None:
-            output_dir = '.'
+            self.output_dir = self.pf.fullpath
         else:
             self.__check_directory(output_dir)
-        self.output_dir = os.path.join(output_dir, os.path.basename(self.pf.fullpath))
+            self.output_dir = os.path.join(output_dir, self.pf.directory)
         self.__check_directory(self.output_dir)
         self.profile_output_dir = os.path.join(self.output_dir, profile_output_dir)
         self.projection_output_dir = os.path.join(self.output_dir, projection_output_dir)
@@ -426,8 +430,9 @@ class HaloProfiler(ParallelAnalysisInterface):
         After all the calls to `add_profile`, this will trigger the actual
         calculations and output the profiles to disk.
 
-        Paramters
-        ---------
+        Parameters
+        ----------
+
         filename : str
             If set, a file will be written with all of the filtered halos
             and the quantities returned by the filter functions.
@@ -454,6 +459,7 @@ class HaloProfiler(ParallelAnalysisInterface):
 
         Examples
         --------
+
         >>> hp.make_profiles(filename="FilteredQuantities.out",
                  prefilters=["halo['mass'] > 1e13"])
 
@@ -606,6 +612,7 @@ class HaloProfiler(ParallelAnalysisInterface):
 
         if newProfile:
             mylog.info("Writing halo %d" % halo['id'])
+            if os.path.exists(filename): os.remove(filename)
             if filename.endswith('.h5'):
                 profile.write_out_h5(filename)
             else:
@@ -684,7 +691,7 @@ class HaloProfiler(ParallelAnalysisInterface):
                 max_val, maxi, mx, my, mz, mg = sphere.quantities['MaxLocation'](self.velocity_center[1],
                                                                                  lazy_reader=True)
                 max_grid = self.pf.h.grids[mg]
-                max_cell = na.unravel_index(maxi, max_grid.ActiveDimensions)
+                max_cell = np.unravel_index(maxi, max_grid.ActiveDimensions)
                 sphere.set_field_parameter('bulk_velocity', [max_grid['x-velocity'][max_cell],
                                                              max_grid['y-velocity'][max_cell],
                                                              max_grid['z-velocity'][max_cell]])
@@ -702,7 +709,8 @@ class HaloProfiler(ParallelAnalysisInterface):
         calculations and saves the output to disk.
 
         Parameters
-        ---------
+        ----------
+
         axes : array_like
             A list of the axes to project along, using the usual 0,1,2
             convention. Default=[0,1,2]
@@ -717,7 +725,9 @@ class HaloProfiler(ParallelAnalysisInterface):
             Default=True.
         njobs : int
             The number of jobs over which to split the projections.  Set
-            to -1 so that each halo is done by a single processor.
+            to -1 so that each halo is done by a single processor.  Halo 
+            projections do not currently work in parallel, so this must 
+            be set to -1.
             Default: -1.
         dynamic : bool
             If True, distribute halos using a task queue.  If False,
@@ -726,11 +736,18 @@ class HaloProfiler(ParallelAnalysisInterface):
 
         Examples
         --------
+
         >>> hp.make_projections(axes=[0, 1, 2], save_cube=True,
             save_images=True, halo_list="filtered")
 
         """
 
+        # Halo projections cannot run in parallel because they are done by 
+        # giving a data source to the projection object.
+        if njobs > 0:
+            mylog.warn("Halo projections cannot use more than one processor per halo, setting njobs to -1.")
+            njobs = -1
+        
         # Get list of halos for projecting.
         if halo_list == 'filtered':
             halo_projection_list = self.filtered_halos
@@ -845,7 +862,7 @@ class HaloProfiler(ParallelAnalysisInterface):
                               (self.projection_output_dir, halo['id'],
                                dataset_name, axis_labels[w])
                             if (frb[hp['field']] != 0).any():
-                                write_image(na.log10(frb[hp['field']]), filename, cmap_name=hp['cmap'])
+                                write_image(np.log10(frb[hp['field']]), filename, cmap_name=hp['cmap'])
                             else:
                                 mylog.info('Projection of %s for halo %d is all zeros, skipping image.' %
                                             (hp['field'], halo['id']))
@@ -863,14 +880,17 @@ class HaloProfiler(ParallelAnalysisInterface):
         to the provided analysis function.
 
         Parameters
-        ---------
+        ----------
+
         analysis_function : function
             A function taking two arguments, the halo dictionary, and a
             sphere object.
-            Example function to calculate total mass of halo:
+            Example function to calculate total mass of halo::
+
                 def my_analysis(halo, sphere):
                     total_mass = sphere.quantities['TotalMass']()
                     print total_mass
+            
         halo_list : {'filtered', 'all'}
             Which set of halos to make profiles of, either ones passed by the
             halo filters (if enabled/added), or all halos.
@@ -889,6 +909,7 @@ class HaloProfiler(ParallelAnalysisInterface):
 
         Examples
         --------
+
         >>> hp.analyze_halo_spheres(my_analysis, halo_list="filtered",
                                     analysis_output_dir='special_analysis')
 
@@ -1076,7 +1097,7 @@ class HaloProfiler(ParallelAnalysisInterface):
                     profile[field].append(float(onLine[q]))
 
         for field in fields:
-            profile[field] = na.array(profile[field])
+            profile[field] = np.array(profile[field])
 
         profile_obj._data = profile
 
@@ -1171,7 +1192,7 @@ class HaloProfiler(ParallelAnalysisInterface):
         for halo in self.filtered_halos:
             for halo_field in halo_fields:
                 if isinstance(halo[halo_field], types.ListType):
-                    field_data = na.array(halo[halo_field])
+                    field_data = np.array(halo[halo_field])
                     field_data.tofile(out_file, sep="\t", format=format)
                 else:
                     if halo_field == 'id':
@@ -1179,7 +1200,7 @@ class HaloProfiler(ParallelAnalysisInterface):
                     else:
                         out_file.write("%s" % halo[halo_field])
                 out_file.write("\t")
-            field_data = na.array([halo[field] for field in fields])
+            field_data = np.array([halo[field] for field in fields])
             field_data.tofile(out_file, sep="\t", format=format)
             out_file.write("\n")
         out_file.close()
@@ -1207,7 +1228,7 @@ class HaloProfiler(ParallelAnalysisInterface):
             value_list = []
             for halo in self.filtered_halos:
                 value_list.append(halo[halo_field])
-            value_list = na.array(value_list)
+            value_list = np.array(value_list)
             out_file.create_dataset(halo_field, data=value_list)
         out_file.close()
 
@@ -1215,7 +1236,7 @@ class HaloProfiler(ParallelAnalysisInterface):
         fid = open(filename, "w")
         fields = [field for field in sorted(profile.keys()) if field != "UsedBins"]
         fid.write("\t".join(["#"] + fields + ["\n"]))
-        field_data = na.array([profile[field] for field in fields])
+        field_data = np.array([profile[field] for field in fields])
         for line in range(field_data.shape[1]):
             field_data[:, line].tofile(fid, sep="\t", format=format)
             fid.write("\n")
@@ -1300,17 +1321,17 @@ def _shift_projections(pf, projections, oldCenter, newCenter, axis):
         add2_y_weight_field = plot['weight_field'][plot['py'] - 0.5 * plot['pdy'] < 0]
 
         # Add the hanging cells back to the projection data.
-        plot.field_data['px'] = na.concatenate([plot['px'], add_x_px, add_y_px,
+        plot.field_data['px'] = np.concatenate([plot['px'], add_x_px, add_y_px,
                                                 add2_x_px, add2_y_px])
-        plot.field_data['py'] = na.concatenate([plot['py'], add_x_py, add_y_py,
+        plot.field_data['py'] = np.concatenate([plot['py'], add_x_py, add_y_py,
                                                 add2_x_py, add2_y_py])
-        plot.field_data['pdx'] = na.concatenate([plot['pdx'], add_x_pdx, add_y_pdx,
+        plot.field_data['pdx'] = np.concatenate([plot['pdx'], add_x_pdx, add_y_pdx,
                                                  add2_x_pdx, add2_y_pdx])
-        plot.field_data['pdy'] = na.concatenate([plot['pdy'], add_x_pdy, add_y_pdy,
+        plot.field_data['pdy'] = np.concatenate([plot['pdy'], add_x_pdy, add_y_pdy,
                                                  add2_x_pdy, add2_y_pdy])
-        plot.field_data[field] = na.concatenate([plot[field], add_x_field, add_y_field,
+        plot.field_data[field] = np.concatenate([plot[field], add_x_field, add_y_field,
                                                  add2_x_field, add2_y_field])
-        plot.field_data['weight_field'] = na.concatenate([plot['weight_field'],
+        plot.field_data['weight_field'] = np.concatenate([plot['weight_field'],
                                                           add_x_weight_field, add_y_weight_field,
                                                           add2_x_weight_field, add2_y_weight_field])
 
