@@ -9,9 +9,9 @@ Author: Britton Smith <brittonsmith@gmail.com>
 Affiliation: MSU
 Author: Chris Malone <chris.m.malone@gmail.com>
 Affiliation: SUNY Stony Brook
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2010 Matthew Turk.  All Rights Reserved.
+  Copyright (C) 2010-2011 Matthew Turk.  All Rights Reserved.
 
   This file is part of yt.
 
