@@ -23,11 +23,12 @@ License:
 import types
 import imp
 import os
-import numpy as na
+import numpy as np
 
 from yt.funcs import *
 import _colormap_data as cmd
 import yt.utilities.lib as au
+import __builtin__
 
 def scale_image(image, mi=None, ma=None):
     r"""Scale an image ([NxNxM] where M = 1-4) to be uint8 and values scaled 
@@ -44,7 +45,7 @@ def scale_image(image, mi=None, ma=None):
 
         >>> image = scale_image(image, min=0, max=1000)
     """
-    if isinstance(image, na.ndarray) and image.dtype == na.uint8:
+    if isinstance(image, np.ndarray) and image.dtype == np.uint8:
         return image
     if isinstance(image, (types.TupleType, types.ListType)):
         image, mi, ma = image
@@ -52,7 +53,7 @@ def scale_image(image, mi=None, ma=None):
         mi = image.min()
     if ma is None:
         ma = image.max()
-    image = (na.clip((image-mi)/(ma-mi) * 255, 0, 255)).astype('uint8')
+    image = (np.clip((image-mi)/(ma-mi) * 255, 0, 255)).astype('uint8')
     return image
 
 def multi_image_composite(fn, red_channel, blue_channel,
@@ -97,37 +98,39 @@ def multi_image_composite(fn, red_channel, blue_channel,
     Examples
     --------
 
-        >>> red_channel = na.log10(frb["Temperature"])
-        >>> blue_channel = na.log10(frb["Density"])
+        >>> red_channel = np.log10(frb["Temperature"])
+        >>> blue_channel = np.log10(frb["Density"])
         >>> multi_image_composite("multi_channel1.png", red_channel, blue_channel)
 
     """
     red_channel = scale_image(red_channel)
     blue_channel = scale_image(blue_channel)
     if green_channel is None:
-        green_channel = na.zeros(red_channel.shape, dtype='uint8')
+        green_channel = np.zeros(red_channel.shape, dtype='uint8')
     else:
         green_channel = scale_image(green_channel)
     if alpha_channel is None:
-        alpha_channel = na.zeros(red_channel.shape, dtype='uint8') + 255
+        alpha_channel = np.zeros(red_channel.shape, dtype='uint8') + 255
     else:
         alpha_channel = scale_image(alpha_channel) 
-    image = na.array([red_channel, green_channel, blue_channel, alpha_channel])
+    image = np.array([red_channel, green_channel, blue_channel, alpha_channel])
     image = image.transpose().copy() # Have to make sure it's contiguous 
     au.write_png(image, fn)
 
-def write_bitmap(bitmap_array, filename, max_val = None, transpose=True):
+def write_bitmap(bitmap_array, filename, max_val = None, transpose=False):
     r"""Write out a bitmapped image directly to a PNG file.
 
     This accepts a three- or four-channel `bitmap_array`.  If the image is not
-    already uint8, it will be scaled and converted.  If it is not four channel, a
-    fourth alpha channel will be added and set to fully opaque.  The resultant
-    image will be directly written to `filename` as a PNG with no colormap
-    applied.  `max_val` is a value used if the array is passed in as anything
-    other than uint8; it will be the value used for scaling and clipping when the
-    array is converted.  Additionally, the minimum is assumed to be zero; this
-    makes it primarily suited for the results of volume rendered images, rather
-    than misaligned projections.
+    already uint8, it will be scaled and converted.  If it is four channel,
+    only the first three channels will be scaled, while the fourth channel is
+    assumed to be in the range of [0,1]. If it is not four channel, a fourth
+    alpha channel will be added and set to fully opaque.  The resultant image
+    will be directly written to `filename` as a PNG with no colormap applied.
+    `max_val` is a value used if the array is passed in as anything other than
+    uint8; it will be the value used for scaling and clipping in the first
+    three channels when the array is converted.  Additionally, the minimum is
+    assumed to be zero; this makes it primarily suited for the results of
+    volume rendered images, rather than misaligned projections.
 
     Parameters
     ----------
@@ -141,19 +144,21 @@ def write_bitmap(bitmap_array, filename, max_val = None, transpose=True):
         The upper limit to clip values to in the output, if converting to uint8.
         If `bitmap_array` is already uint8, this will be ignore.
     """
-    if bitmap_array.dtype != na.uint8:
-        if max_val is None: max_val = bitmap_array.max()
-        bitmap_array = na.clip(bitmap_array / max_val, 0.0, 1.0) * 255
-        bitmap_array = bitmap_array.astype("uint8")
     if len(bitmap_array.shape) != 3 or bitmap_array.shape[-1] not in (3,4):
         raise RuntimeError
-    if bitmap_array.shape[-1] == 3:
+    if bitmap_array.dtype != np.uint8:
         s1, s2 = bitmap_array.shape[:2]
-        alpha_channel = 255*na.ones((s1,s2,1), dtype='uint8')
-        bitmap_array = na.concatenate([bitmap_array, alpha_channel], axis=-1)
+        if bitmap_array.shape[-1] == 3:
+            alpha_channel = 255*np.ones((s1,s2,1), dtype='uint8')
+        else:
+            alpha_channel = (255*bitmap_array[:,:,3]).astype('uint8')
+            alpha_channel.shape = s1, s2, 1
+        if max_val is None: max_val = bitmap_array[:,:,:3].max()
+        bitmap_array = np.clip(bitmap_array[:,:,:3] / max_val, 0.0, 1.0) * 255
+        bitmap_array = np.concatenate([bitmap_array.astype('uint8'),
+                                       alpha_channel], axis=-1)
     if transpose:
-        for channel in range(bitmap_array.shape[2]):
-            bitmap_array[:,:,channel] = bitmap_array[:,:,channel].T
+        bitmap_array = bitmap_array.swapaxes(0,1)
     if filename is not None:
         au.write_png(bitmap_array.copy(), filename)
     else:
@@ -229,14 +234,14 @@ def apply_colormap(image, color_bounds = None, cmap_name = 'algae', func=lambda
     """
     image = func(image)
     if color_bounds is None:
-        mi = na.nanmin(image[~na.isinf(image)])
-        ma = na.nanmax(image[~na.isinf(image)])
+        mi = np.nanmin(image[~np.isinf(image)])
+        ma = np.nanmax(image[~np.isinf(image)])
         color_bounds = mi, ma
     else:
         color_bounds = [func(c) for c in color_bounds]
     image = (image - color_bounds[0])/(color_bounds[1] - color_bounds[0])
     to_plot = map_to_colors(image, cmap_name)
-    to_plot = na.clip(to_plot, 0, 255)
+    to_plot = np.clip(to_plot, 0, 255)
     return to_plot
 
 def annotate_image(image, text, xpos, ypos, font_name = "Vera",
@@ -279,7 +284,7 @@ def annotate_image(image, text, xpos, ypos, font_name = "Vera",
     >>> annotate_image(bitmap, "Hello!", 0, 100)
     >>> write_bitmap(bitmap, "saved.png")
     """
-    if len(image.shape) != 3 or image.dtype != na.uint8:
+    if len(image.shape) != 3 or image.dtype != np.uint8:
         raise RuntimeError("This routine requires a UINT8 bitmapped image.")
     font_path = os.path.join(imp.find_module("matplotlib")[1],
                              "mpl-data/fonts/ttf/",
@@ -295,10 +300,10 @@ def map_to_colors(buff, cmap_name):
         print "Your color map was not found in the extracted colormap file."
         raise KeyError(cmap_name)
     lut = cmd.color_map_luts[cmap_name]
-    x = na.mgrid[0.0:1.0:lut[0].shape[0]*1j]
+    x = np.mgrid[0.0:1.0:lut[0].shape[0]*1j]
     shape = buff.shape
-    mapped = na.dstack(
-            [(na.interp(buff, x, v)*255) for v in lut ]).astype("uint8")
+    mapped = np.dstack(
+            [(np.interp(buff, x, v)*255) for v in lut ]).astype("uint8")
     return mapped.copy("C")
 
 def strip_colormap_data(fn = "color_map_data.py",
@@ -336,8 +341,8 @@ def splat_points(image, points_x, points_y,
     return im
 
 def write_projection(data, filename, colorbar=True, colorbar_label=None, 
-                     title=None, limits=None, take_log=True, var_fig_size=False,
-                     cmap='algae'):
+                     title=None, limits=None, take_log=True, figsize=(8,6),
+                     dpi=100, cmap_name='algae'):
     r"""Write a projection or volume rendering to disk with a variety of 
     pretty parameters such as limits, title, colorbar, etc.  write_projection
     uses the standard matplotlib interface to create the figure.  N.B. This code
@@ -345,7 +350,8 @@ def write_projection(data, filename, colorbar=True, colorbar_label=None,
     framework (i.e. the Camera interface or off_axis_projection).
 
     Accepts an NxM sized array representing the projection itself as well
-    as the filename to which you will save this figure.  
+    as the filename to which you will save this figure.  Note that the final
+    resolution of your image will be a product of dpi/100 * figsize.
 
     Parameters
     ----------
@@ -364,10 +370,11 @@ def write_projection(data, filename, colorbar=True, colorbar_label=None,
         of the data array
     take_log : boolean
         plot the log of the data array (and take the log of the limits if set)?
-    var_fig_size : boolean
-        If we want the resolution (and size) of the output image to scale 
-        with the resolution of the image array.  
-    cmap : string
+    figsize : array_like
+        width, height in inches of final image
+    dpi : int
+        final image resolution in pixels / inch
+    cmap_name : string
         The name of the colormap.
 
     Examples
@@ -376,11 +383,11 @@ def write_projection(data, filename, colorbar=True, colorbar_label=None,
     >>> image = off_axis_projection(pf, c, L, W, N, "Density", no_ghost=False)
     >>> write_projection(image, 'test.png', 
                          colorbar_label="Column Density (cm$^{-2}$)", 
-                         title="Offaxis Projection", limits=(1e-3,1e-5), 
+                         title="Offaxis Projection", limits=(1e-5,1e-3), 
                          take_log=True)
     """
     import matplotlib
-    from ._mpl_imports import *
+    from ._mpl_imports import FigureCanvasAgg, FigureCanvasPdf, FigureCanvasPS
 
     # If this is rendered as log, then apply now.
     if take_log:
@@ -392,11 +399,11 @@ def write_projection(data, filename, colorbar=True, colorbar_label=None,
         limits = [None, None]
 
     # Create the figure and paint the data on
-    fig = matplotlib.figure.Figure()
+    fig = matplotlib.figure.Figure(figsize=figsize)
     ax = fig.add_subplot(111)
     fig.tight_layout()
 
-    cax = ax.imshow(data, vmin=limits[0], vmax=limits[1], norm=norm, cmap=cmap)
+    cax = ax.imshow(data, vmin=limits[0], vmax=limits[1], norm=norm, cmap=cmap_name)
     
     if title:
         ax.set_title(title)
@@ -411,37 +418,27 @@ def write_projection(data, filename, colorbar=True, colorbar_label=None,
         if colorbar_label:
             cbar.ax.set_ylabel(colorbar_label)
 
-    # If we want the resolution of the image to scale with the resolution
-    # of the image array. we increase the dpi value accordingly
-    
-    if var_fig_size:
-        N = data.shape[0]
-        mag_factor = N/480.
-        dpi = 100*mag_factor
-    else:
-        dpi = None
+    suffix = get_image_suffix(filename)
 
-    if filename[-4:] == '.png':
-        suffix = ''
-    else:
+    if suffix == '':
         suffix = '.png'
         filename = "%s%s" % (filename, suffix)
-    mylog.info("Saving plot %s", fn)
+    mylog.info("Saving plot %s", filename)
     if suffix == ".png":
         canvas = FigureCanvasAgg(fig)
     elif suffix == ".pdf":
         canvas = FigureCanvasPdf(fig)
     elif suffix in (".eps", ".ps"):
-        canvas = FigureCanvasPS
+        canvas = FigureCanvasPS(fig)
     else:
         mylog.warning("Unknown suffix %s, defaulting to Agg", suffix)
         canvas = FigureCanvasAgg(fig)
-    canvas.print_figure(filename)
+
+    canvas.print_figure(filename, dpi=dpi)
     return filename
 
 
 def write_fits(image, filename_prefix, clobber=True, coords=None, gzip_file=False) :
-
     """
     This will export a FITS image of a floating point array. The output filename is
     *filename_prefix*. If clobber is set to True, this will overwrite any existing
@@ -505,4 +502,32 @@ def write_fits(image, filename_prefix, clobber=True, coords=None, gzip_file=Fals
         clob = ""
         if (clobber) : clob="-f"
         system("gzip "+clob+" %s.fits" % (filename_prefix))
+
+def display_in_notebook(image, max_val=None):
+    """
+    A helper function to display images in an IPython notebook
     
+    Must be run from within an IPython notebook, or else it will raise
+    a YTNotInsideNotebook exception.
+        
+    Parameters
+    ----------
+    image : array_like
+        This is an (unscaled) array of floating point values, shape (N,N,3) or
+        (N,N,4) to display in the notebook. The first three channels will be
+        scaled automatically.  
+    max_val : float, optional
+        The upper limit to clip values of the image.  Only applies to the first
+        three channels.
+    """
+ 
+    if "__IPYTHON__" in dir(__builtin__):
+        from IPython.core.displaypub import publish_display_data
+        data = write_bitmap(image, None, max_val=max_val)
+        publish_display_data(
+            'yt.visualization.image_writer.display_in_notebook',
+            {'image/png' : data}
+        )
+    else:
+        raise YTNotInsideNotebook
+
